@@ -27,15 +27,21 @@
  *
  */
 #include <fcntl.h>
-#include <machine/apm_bios.h>
 #include <sys/ioctl.h>
 #include <unistd.h>
+
 #include "config.h"
 #include "conky.h"
 #include "text_object.h"
 
-#define APMDEV "/dev/apm"
-#define APM_UNKNOWN 255
+#if defined(__OpenBSD__)
+#include <machine/apmvar.h>
+#else
+#include <machine/apm_bios.h>
+#endif
+
+const char *APMDEV = "/dev/apm";
+const u_int APM_UNKNOWN = 255;
 
 #ifndef APM_AC_OFF
 #define APM_AC_OFF 0
@@ -49,27 +55,26 @@
 #define APM_BATT_CHARGING 3
 #endif
 
-static int apm_getinfo(int fd, apm_info_t aip) {
 #ifdef __OpenBSD__
-  if (ioctl(fd, APM_IOC_GETPOWER, aip) == -1) {
+const u_long GET_APM_INFO = APM_IOC_GETPOWER;
+using apm_info = apm_power_info;
+#define seconds_left minutes_left * 1000
 #else
-  if (ioctl(fd, APMIO_GETINFO, aip) == -1) {
+const u_long GET_APM_INFO = APMIO_GETINFO;
+#define ac_state ai_acline
+#define battery_state ai_batt_stat
+#define battery_life ai_batt_life
+#define seconds_left ai_batt_time
 #endif
-    return -1;
-  }
 
-  return 0;
+static bool apm_getinfo(int fd, apm_info *aip) {
+  return ioctl(fd, GET_APM_INFO, aip) == -1;
 }
 
 void print_apm_adapter(struct text_object *obj, char *p,
                        unsigned int p_max_size) {
   int fd;
-  const char *out;
-#ifdef __OpenBSD__
-  struct apm_power_info a_info;
-#else
-  struct apm_info a_info;
-#endif
+  apm_info info;
 
   (void)obj;
 
@@ -79,25 +84,20 @@ void print_apm_adapter(struct text_object *obj, char *p,
     return;
   }
 
-  if (apm_getinfo(fd, &a_info) != 0) {
+  if (!apm_getinfo(fd, &info)) {
     close(fd);
     snprintf(p, p_max_size, "%s", "ERR");
     return;
   }
   close(fd);
 
-#ifdef __OpenBSD__
-#define ai_acline ac_state
-#endif
-  switch (a_info.ai_acline) {
+  const char *out;
+  switch (info.ac_state) {
     case APM_AC_OFF:
       out = "off-line";
       break;
     case APM_AC_ON:
-#ifdef __OpenBSD__
-#define ai_batt_stat battery_state
-#endif
-      if (a_info.ai_batt_stat == APM_BATT_CHARGING) {
+      if (info.battery_state == APM_BATT_CHARGING) {
         out = "charging";
       } else {
         out = "on-line";
@@ -113,13 +113,7 @@ void print_apm_adapter(struct text_object *obj, char *p,
 void print_apm_battery_life(struct text_object *obj, char *p,
                             unsigned int p_max_size) {
   int fd;
-  u_int batt_life;
-  const char *out;
-#ifdef __OpenBSD__
-  struct apm_power_info a_info;
-#else
-  struct apm_info a_info;
-#endif
+  apm_info info;
 
   (void)obj;
 
@@ -129,40 +123,33 @@ void print_apm_battery_life(struct text_object *obj, char *p,
     return;
   }
 
-  if (apm_getinfo(fd, &a_info) != 0) {
+  if (!apm_getinfo(fd, &info)) {
     close(fd);
     snprintf(p, p_max_size, "%s", "ERR");
     return;
   }
   close(fd);
 
-#ifdef __OpenBSD__
-#define ai_batt_life battery_life
-#endif
-  batt_life = a_info.ai_batt_life;
-  if (batt_life == APM_UNKNOWN) {
-    out = "unknown";
-  } else if (batt_life <= 100) {
-    snprintf(p, p_max_size, "%d%%", batt_life);
+  if (info.battery_life <= 100) {
+    snprintf(p, p_max_size, "%d%%", info.battery_life);
     return;
+  }
+
+  const char *out;
+  if (info.battery_life == APM_UNKNOWN) {
+    out = "unknown";
   } else {
     out = "ERR";
   }
-
+  
   snprintf(p, p_max_size, "%s", out);
 }
 
 void print_apm_battery_time(struct text_object *obj, char *p,
                             unsigned int p_max_size) {
   int fd;
-  int batt_time;
-#ifdef __OpenBSD__
-  int h, m;
-  struct apm_power_info a_info;
-#else
   int h, m, s;
-  struct apm_info a_info;
-#endif
+  apm_info info;
 
   (void)obj;
 
@@ -172,29 +159,17 @@ void print_apm_battery_time(struct text_object *obj, char *p,
     return;
   }
 
-  if (apm_getinfo(fd, &a_info) != 0) {
+  if (!apm_getinfo(fd, &info)) {
     close(fd);
     snprintf(p, p_max_size, "%s", "ERR");
     return;
   }
   close(fd);
 
-#ifdef __OpenBSD__
-#define ai_batt_time minutes_left
-#endif
-  batt_time = a_info.ai_batt_time;
-
+  int batt_time = info.seconds_left;
   if (batt_time == -1) {
     snprintf(p, p_max_size, "%s", "unknown");
-  } else
-#ifdef __OpenBSD__
-  {
-    h = batt_time / 60;
-    m = batt_time % 60;
-    snprintf(p, p_max_size, "%2d:%02d", h, m);
-  }
-#else
-  {
+  } else {
     h = batt_time;
     s = h % 60;
     h /= 60;
@@ -202,5 +177,4 @@ void print_apm_battery_time(struct text_object *obj, char *p,
     h /= 60;
     snprintf(p, p_max_size, "%2d:%02d:%02d", h, m, s);
   }
-#endif
 }
