@@ -56,8 +56,6 @@ void register_output<output_t::FILE>(display_outputs_t &outputs) {
 
 display_output_file::display_output_file(const std::string &name_)
     : display_output_base(name_) {
-  // lowest priority, it's a fallback
-  priority = 0;
 }
 
 bool display_output_file::detect() {
