@@ -243,7 +243,6 @@ void register_output<output_t::WAYLAND>(display_outputs_t &outputs) {
 display_output_wayland::display_output_wayland()
     : display_output_base("wayland") {
   is_graphical = true;
-  priority = 2;
 }
 
 bool display_output_wayland::detect() {
@@ -661,7 +660,7 @@ bool display_output_wayland::main_loop_wait(double t) {
          text_size.y() + 2 * border_total != height || scale_changed)) {
       /* clamp text_width to configured maximum */
       if (maximum_width.get(*state)) {
-        int mw = maximum_width.get(*state);
+        int mw = global_window->scale * maximum_width.get(*state);
         if (mw > 0) { text_size.set_x(std::min(mw, text_size.x())); }
       }
 
@@ -785,9 +784,6 @@ void display_output_wayland::cleanup() {
 
 void display_output_wayland::set_foreground_color(Colour c) {
   current_color = c;
-#ifdef BUILD_ARGB
-  current_color.alpha = own_window_argb_value.get(*state);
-#endif /* BUILD_ARGB */
   if (global_window->cr) {
     cairo_set_source_rgba(global_window->cr, current_color.red / 255.0,
                           current_color.green / 255.0,
@@ -927,8 +923,10 @@ void display_output_wayland::clear_text(int exposures) {
 
   cairo_set_source_rgba(window->cr, color.red / 255.0, color.green / 255.0,
                         color.blue / 255.0, color.alpha / 255.0);
-  cairo_set_operator(window->cr, CAIRO_OPERATOR_SOURCE);
-  cairo_paint(window->cr);
+  cairo_set_operator(window->cr, CAIRO_OPERATOR_CLEAR);
+  cairo_rectangle(window->cr, 0, 0, window->rectangle.width(),
+                  window->rectangle.height());
+  cairo_fill(window->cr);
   cairo_restore(window->cr);
 }
 
@@ -1056,7 +1054,7 @@ static struct wl_shm_pool *make_shm_pool(struct wl_shm *shm, int size,
     return NULL;
   }
 
-  *data = mmap(NULL, size, PROT_READ | PROT_WRITE, MAP_PRIVATE, fd, 0);
+  *data = mmap(NULL, size, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
   if (*data == MAP_FAILED) {
     fprintf(stderr, "mmap failed: %m\n");
     close(fd);
