@@ -42,6 +42,8 @@
 #include "dragonfly.h"
 #elif defined(__OpenBSD__)
 #include "openbsd.h"
+#elif defined(__NetBSD__)
+#include "netbsd.h"
 #elif defined(__sun)
 #include "solaris.h"
 #elif defined(__HAIKU__)
