@@ -49,8 +49,12 @@
 
 #if defined(__FreeBSD__)
 #include "freebsd.h"
+#elif defined(__OpenBSD__)
+#include "openbsd.h"
 #elif defined(__DragonFly__)
 #include "dragonfly.h"
+#elif defined(__NetBSD__)
+#include "netbsd.h"
 #elif defined(__HAIKU__)
 #include "haiku.h"
 #elif defined(__APPLE__) && defined(__MACH__)
@@ -59,7 +63,8 @@
 
 #if !defined(HAVE_STRUCT_STATFS_F_FSTYPENAME) && !defined(__OpenBSD__) &&  \
     !defined(__FreeBSD__) && !defined(__DragonFly__) && !defined(__sun) && \
-    !defined(__HAIKU__) && !(defined(__APPLE__) && defined(__MACH__))
+    !defined(__HAIKU__) && !(defined(__APPLE__) && defined(__MACH__)) && \
+    !defined(__NetBSD__)
 #include <mntent.h>
 #endif
 
@@ -113,16 +118,20 @@ struct fs_stat *prepare_fs_stat(const char *s) {
   }
   strncpy(next->path, s, DEFAULT_TEXT_BUFFER_SIZE);
   next->set = 1;
+  next->errored = 0;
   update_fs_stat(next);
   return next;
 }
 
 #if defined(__APPLE__)
-#define statfs_func statfs
-#define statfs_struct statfs
+  #define statfs_func statfs
+  #define statfs_struct statfs
+#elif defined(__NetBSD__)
+  #define statfs_func statvfs
+  #define statfs_struct statvfs
 #else
-#define statfs_func statfs64
-#define statfs_struct statfs64
+  #define statfs_func statfs64
+  #define statfs_struct statfs64
 #endif /* defined(__APPLE__) */
 
 static void update_fs_stat(struct fs_stat *fs) {
@@ -142,10 +151,14 @@ static void update_fs_stat(struct fs_stat *fs) {
     /* bfree (root) or bavail (non-roots) ? */
     fs->avail = static_cast<long long>(s.f_bavail) * s.f_bsize;
     fs->free = static_cast<long long>(s.f_bfree) * s.f_bsize;
+    fs->errored = 0;
     get_fs_type(fs->path, fs->type);
 #endif
   } else {
-    NORM_ERR("statfs '%s': %s", fs->path, strerror(errno));
+    if (fs->errored == 0) {
+      NORM_ERR("statfs '%s': %s", fs->path, strerror(errno));
+      fs->errored = 1;
+    }
     fs->size = 0;
     fs->avail = 0;
     fs->free = 0;
@@ -156,7 +169,7 @@ static void update_fs_stat(struct fs_stat *fs) {
 void get_fs_type(const char *path, char *result) {
 #if defined(HAVE_STRUCT_STATFS_F_FSTYPENAME) || defined(__FreeBSD__) ||     \
     defined(__OpenBSD__) || defined(__DragonFly__) || defined(__HAIKU__) || \
-    (defined(__APPLE__) && defined(__MACH__))
+    (defined(__APPLE__) && defined(__MACH__)) || defined(__NetBSD__)
 
   struct statfs_struct s {};
   if (statfs_func(path, &s) == 0) {
