@@ -9,7 +9,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2021 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2024 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -30,6 +30,7 @@
 #ifndef _LOGGING_H
 #define _LOGGING_H
 
+#include <cinttypes>  // correct formatting for int types
 #include <cstdio>
 #include <stdexcept>
 #include "config.h"
@@ -81,8 +82,10 @@ void NORM_ERR(const char *format, Args &&...args) {
 
 /* critical error with additional cleanup */
 template <typename... Args>
-inline void CRIT_ERR_FREE(void *memtofree1, void *memtofree2,
-                          const char *format, Args &&...args) {
+__attribute__((noreturn)) inline void CRIT_ERR_FREE(void *memtofree1,
+                                                    void *memtofree2,
+                                                    const char *format,
+                                                    Args &&...args) {
   NORM_ERR(format, args...);
   free(memtofree1);
   free(memtofree2);
@@ -92,7 +95,8 @@ inline void CRIT_ERR_FREE(void *memtofree1, void *memtofree2,
 
 /* critical error */
 template <typename... Args>
-inline void CRIT_ERR(const char *format, Args &&...args) {
+__attribute__((noreturn)) inline void CRIT_ERR(const char *format,
+                                               Args &&...args) {
   CRIT_ERR_FREE(nullptr, nullptr, format, args...);
 }
 
