@@ -334,7 +334,7 @@ void parse_net_stat_graph_arg(struct text_object *obj, const char *arg,
                               void *free_at_crash) {
   /* scan arguments and get interface name back */
   auto [buf, skip] = scan_command(arg);
-  scan_graph(obj, arg + skip, 0);
+  scan_graph(obj, arg + skip, 0, TRUE);
 
   // default to DEFAULTNETDEV
   if (buf != nullptr) {
