@@ -28,12 +28,13 @@
  */
 
 #include <kvm.h>
-#include <sys/dkstat.h>
 #include <sys/ioctl.h>
 #include <sys/malloc.h>
 #include <sys/param.h>
 #include <sys/resource.h>
+#include <sys/proc.h>
 #include <sys/sensors.h>
+#include <sys/sched.h>
 #include <sys/socket.h>
 #include <sys/swap.h>
 #include <sys/sysctl.h>
@@ -62,6 +63,7 @@
 #include "logging.h"
 #include "net_stat.h"
 #include "openbsd.h"
+#include "temphelper.h"
 #include "top.h"
 
 #define MAXSHOWDEVS 16
@@ -71,14 +73,21 @@
 
 inline void proc_find_top(struct process **cpu, struct process **mem);
 
-static short cpu_setup = 0;
 static kvm_t *kd = 0;
 
 struct ifmibdata *data = nullptr;
 size_t len = 0;
 
-int init_kvm = 0;
-int init_sensors = 0;
+static int init_cpu = 0;
+static int init_kvm = 0;
+static int init_sensors = 0;
+
+struct cpu_load {
+  u_int64_t old_used;
+  u_int64_t old_total;
+};
+
+static struct cpu_load *cpu_loads = nullptr;
 
 static int kvm_init() {
   if (init_kvm) { return 1; }
@@ -103,7 +112,7 @@ static int swapmode(int *used, int *total) {
   nswap = swapctl(SWAP_NSWAP, 0, 0);
   if (nswap == 0) { return 0; }
 
-  swdev = malloc(nswap * sizeof(*swdev));
+  swdev = (struct swapent *)malloc(nswap * sizeof(*swdev));
   if (swdev == nullptr) { return 0; }
 
   rnswap = swapctl(SWAP_STATS, swdev, nswap);
@@ -132,7 +141,7 @@ int check_mount(struct text_object *obj) {
   return 0;
 }
 
-void update_uptime() {
+int update_uptime() {
   int mib[2] = {CTL_KERN, KERN_BOOTTIME};
   struct timeval boottime;
   time_t now;
@@ -146,9 +155,11 @@ void update_uptime() {
     NORM_ERR("Could not get uptime");
     info.uptime = 0;
   }
+
+  return 0;
 }
 
-void update_meminfo() {
+int update_meminfo() {
   static int mib[2] = {CTL_VM, VM_METER};
   struct vmtotal vmtotal;
   size_t size;
@@ -185,9 +196,11 @@ void update_meminfo() {
     info.swap = 0;
     info.swapfree = 0;
   }
+
+  return 0;
 }
 
-void update_net_stats() {
+int update_net_stats() {
   struct net_stat *ns;
   double delta;
   long long r, t, last_recv, last_trans;
@@ -196,9 +209,9 @@ void update_net_stats() {
 
   /* get delta */
   delta = current_update_time - last_update_time;
-  if (delta <= 0.0001) { return; }
+  if (delta <= 0.0001) { return 0; }
 
-  if (getifaddrs(&ifap) < 0) { return; }
+  if (getifaddrs(&ifap) < 0) { return 0; }
 
   for (ifa = ifap; ifa; ifa = ifa->ifa_next) {
     ns = get_net_stat((const char *)ifa->ifa_name, nullptr, NULL);
@@ -249,164 +262,131 @@ void update_net_stats() {
   }
 
   freeifaddrs(ifap);
+
+  return 0;
 }
 
 int update_total_processes() {
   int n_processes;
 
   kvm_init();
-  kvm_getprocs(kd, KERN_PROC_ALL, 0, &n_processes);
+  kvm_getprocs(kd, KERN_PROC_ALL, 0, sizeof(struct kinfo_proc),  &n_processes);
 
   info.procs = n_processes;
 
   return 0;
 }
 
-void update_running_processes() {
-  struct kinfo_proc2 *p;
+int update_running_processes() {
+  struct kinfo_proc *p;
   int n_processes;
   int i, cnt = 0;
 
   kvm_init();
-  int max_size = sizeof(struct kinfo_proc2);
+  int max_size = sizeof(struct kinfo_proc);
 
-  p = kvm_getproc2(kd, KERN_PROC_ALL, 0, max_size, &n_processes);
+  p = kvm_getprocs(kd, KERN_PROC_ALL, 0, max_size, &n_processes);
   for (i = 0; i < n_processes; i++) {
     if (p[i].p_stat == SRUN) { cnt++; }
   }
 
   info.run_procs = cnt;
+  return 0;
 }
 
-/* new SMP code can be enabled by commenting the following line */
-#define OLDCPU
-
-#ifdef OLDCPU
-struct cpu_load_struct {
-  unsigned long load[5];
-};
-
-struct cpu_load_struct fresh = {{0, 0, 0, 0, 0}};
-long cpu_used, oldtotal, oldused;
-#else
-#include <assert.h>
-int64_t *fresh = nullptr;
-
-/* XXX is 8 enough? - What's the constant for MAXCPU? */
-/* allocate this with malloc would be better */
-int64_t oldtotal[8], oldused[8];
-#endif
-
 void get_cpu_count() {
-  int cpu_count = 1; /* default to 1 cpu */
-#ifndef OLDCPU
+  int cpu_count = 0;
   int mib[2] = {CTL_HW, HW_NCPU};
-  size_t len = sizeof(cpu_count);
+  size_t size = sizeof(cpu_count);
 
-  if (sysctl(mib, 2, &cpu_count, &len, nullptr, 0) != 0) {
-    NORM_ERR("error getting cpu count, defaulting to 1");
+  if (sysctl(mib, 2, &cpu_count, &size, nullptr, 0) != 0) {
+    NORM_ERR("unable to get hw.ncpu, defaulting to 1");
+    info.cpu_count = 1;
+  } else {
+    info.cpu_count = cpu_count;
   }
-#endif
-  info.cpu_count = cpu_count;
 
-  info.cpu_usage = malloc(info.cpu_count * sizeof(float));
-  if (info.cpu_usage == nullptr) { CRIT_ERR("malloc"); }
+  // [1, 2, ..., N] - CPU0, CPU1, ..., CPUN-1
+  info.cpu_usage = (float *)calloc(info.cpu_count + 1, sizeof(float));
+  if (info.cpu_usage == nullptr) {
+    CRIT_ERR("calloc");
+  }
 
-#ifndef OLDCPU
-  assert(fresh == nullptr); /* XXX Is this leaking memory? */
-  /* XXX Where shall I free this? */
-  if (nullptr == (fresh = calloc(cpu_count, sizeof(int64_t) * CPUSTATES))) {
+  cpu_loads = (struct cpu_load*)calloc(info.cpu_count + 1, sizeof(struct cpu_load));
+  if (cpu_loads == nullptr) {
     CRIT_ERR("calloc");
   }
-#endif
 }
 
-void update_cpu_usage() {
-#ifdef OLDCPU
-  int mib[2] = {CTL_KERN, KERN_CPTIME};
-  long used, total;
+int update_cpu_usage() {
   long cp_time[CPUSTATES];
-  size_t len = sizeof(cp_time);
-#else
+  int mib_cp_time[2] = {CTL_KERN, KERN_CPTIME};
+  u_int64_t cp_time2[CPUSTATES];
+  int mib_cp_time2[3] = {CTL_KERN, KERN_CPTIME2, 0};
   size_t size;
-  unsigned int i;
-#endif
+  u_int64_t used = 0, total = 0;
 
-  /* add check for !info.cpu_usage since that mem is freed on a SIGUSR1 */
-  if ((cpu_setup == 0) || (!info.cpu_usage)) {
+  if (init_cpu == 0){
     get_cpu_count();
-    cpu_setup = 1;
+    init_cpu = 1;
   }
 
-#ifdef OLDCPU
-  if (sysctl(mib, 2, &cp_time, &len, nullptr, 0) < 0) {
-    NORM_ERR("Cannot get kern.cp_time");
+  size = sizeof(cp_time);
+  if (sysctl(mib_cp_time, 2, &cp_time, &size, nullptr, 0) != 0) {
+      NORM_ERR("unable to get kern.cp_time");
+      return 1;
   }
 
-  fresh.load[0] = cp_time[CP_USER];
-  fresh.load[1] = cp_time[CP_NICE];
-  fresh.load[2] = cp_time[CP_SYS];
-  fresh.load[3] = cp_time[CP_IDLE];
-  fresh.load[4] = cp_time[CP_IDLE];
+  for (int j = 0; j < CPUSTATES; ++j) {
+    total += cp_time[j];
+  }
+  used = total - cp_time[CP_IDLE];
 
-  used = fresh.load[0] + fresh.load[1] + fresh.load[2];
-  total = fresh.load[0] + fresh.load[1] + fresh.load[2] + fresh.load[3];
-
-  if ((total - oldtotal) != 0) {
-    info.cpu_usage[0] = ((double)(used - oldused)) / (double)(total - oldtotal);
+  if ((total - cpu_loads[0].old_total) != 0) {
+    const float diff_used = (float)(used - cpu_loads[0].old_used);
+    const float diff_total = (float)(total - cpu_loads[0].old_total);
+    info.cpu_usage[0] = diff_used / diff_total;
   } else {
     info.cpu_usage[0] = 0;
   }
+  cpu_loads[0].old_used = used;
+  cpu_loads[0].old_total = total;
 
-  oldused = used;
-  oldtotal = total;
-#else
-  if (info.cpu_count > 1) {
-    size = CPUSTATES * sizeof(int64_t);
-    for (i = 0; i < info.cpu_count; i++) {
-      int cp_time_mib[] = {CTL_KERN, KERN_CPTIME2, i};
-      if (sysctl(cp_time_mib, 3, &(fresh[i * CPUSTATES]), &size, nullptr, 0) <
-          0) {
-        NORM_ERR("sysctl kern.cp_time2 failed");
-      }
-    }
-  } else {
-    int cp_time_mib[] = {CTL_KERN, KERN_CPTIME};
-    long cp_time_tmp[CPUSTATES];
-
-    size = sizeof(cp_time_tmp);
-    if (sysctl(cp_time_mib, 2, cp_time_tmp, &size, nullptr, 0) < 0) {
-      NORM_ERR("sysctl kern.cp_time failed");
+  for (int i = 0; i < info.cpu_count; ++i) {
+    mib_cp_time2[2] = i;
+    size = sizeof(cp_time2);
+    if (sysctl(mib_cp_time2, 3, &cp_time2, &size, nullptr, 0) != 0) {
+      NORM_ERR("unable to get kern.cp_time2 for cpu%d", i);
+      return 1;
     }
 
-    for (i = 0; i < CPUSTATES; i++) { fresh[i] = (int64_t)cp_time_tmp[i]; }
-  }
+    total = 0;
+    used = 0;
+    for (int j = 0; j < CPUSTATES; ++j) {
+      total += cp_time2[j];
+    }
+    used = total - cp_time2[CP_IDLE];
 
-  /* XXX Do sg with this int64_t => long => double ? float hell. */
-  for (i = 0; i < info.cpu_count; i++) {
-    int64_t used, total;
-    int at = i * CPUSTATES;
-
-    used = fresh[at + CP_USER] + fresh[at + CP_NICE] + fresh[at + CP_SYS];
-    total = used + fresh[at + CP_IDLE];
-
-    if ((total - oldtotal[i]) != 0) {
-      info.cpu_usage[i] =
-          ((double)(used - oldused[i])) / (double)(total - oldtotal[i]);
+    const int n = i + 1; // [0] is the total CPU, must shift by 1
+    if ((total - cpu_loads[n].old_total) != 0) {
+      const float diff_used = (float)(used - cpu_loads[n].old_used);
+      const float diff_total = (float)(total - cpu_loads[n].old_total);
+      info.cpu_usage[n] = diff_used / diff_total;
     } else {
-      info.cpu_usage[i] = 0;
+      info.cpu_usage[n] = 0;
     }
 
-    oldused[i] = used;
-    oldtotal[i] = total;
+    cpu_loads[n].old_used = used;
+    cpu_loads[n].old_total = total;
   }
-#endif
+
+  return 0;
 }
 
 void free_cpu(struct text_object *) { /* no-op */
 }
 
-void update_load_average() {
+int update_load_average() {
   double v[3];
 
   getloadavg(v, 3);
@@ -414,8 +394,11 @@ void update_load_average() {
   info.loadavg[0] = (float)v[0];
   info.loadavg[1] = (float)v[1];
   info.loadavg[2] = (float)v[2];
+
+  return 0;
 }
 
+#define MAXSENSORDEVICES 128
 #define OBSD_MAX_SENSORS 256
 static struct obsd_sensors_struct {
   int device;
@@ -428,7 +411,7 @@ static conky::simple_config_setting<int> sensor_device("sensor_device", 0,
                                                        false);
 
 /* read sensors from sysctl */
-void update_obsd_sensors() {
+int update_obsd_sensors() {
   int sensor_cnt, dev, numt, mib[5] = {CTL_HW, HW_SENSORS, 0, 0, 0};
   struct sensor sensor;
   struct sensordev sensordev;
@@ -446,10 +429,11 @@ void update_obsd_sensors() {
   mib[2] = dev;
   if (sysctl(mib, 3, &sensordev, &sdlen, nullptr, 0) == -1) {
     if (errno != ENOENT) { warn("sysctl"); }
-    return;
+    return 0;
     // continue;
   }
-  for (type = 0; type < SENSOR_MAX_TYPES; type++) {
+  for (int t = 0; t < SENSOR_MAX_TYPES; t++) {
+    type = (enum sensor_type) t;
     mib[3] = type;
     for (numt = 0; numt < sensordev.maxnumt[type]; numt++) {
       mib[4] = numt;
@@ -480,6 +464,8 @@ void update_obsd_sensors() {
   /* } */
 
   init_sensors = 1;
+
+  return 0;
 }
 
 void parse_obsd_sensor(struct text_object *obj, const char *arg) {
@@ -491,21 +477,24 @@ void parse_obsd_sensor(struct text_object *obj, const char *arg) {
     obj->data.l = atoi(&arg[0]);
 }
 
-void print_obsd_sensors_temp(struct text_object *obj, char *p, int p_max_size) {
+void print_obsd_sensors_temp(struct text_object *obj, char *p,
+                             unsigned int p_max_size) {
   obsd_sensors.device = sensor_device.get(*state);
   update_obsd_sensors();
   temp_print(p, p_max_size, obsd_sensors.temp[obsd_sensors.device][obj->data.l],
              TEMP_CELSIUS, 1);
 }
 
-void print_obsd_sensors_fan(struct text_object *obj, char *p, int p_max_size) {
+void print_obsd_sensors_fan(struct text_object *obj, char *p,
+                            unsigned int p_max_size) {
   obsd_sensors.device = sensor_device.get(*state);
   update_obsd_sensors();
   snprintf(p, p_max_size, "%d",
            obsd_sensors.fan[obsd_sensors.device][obj->data.l]);
 }
 
-void print_obsd_sensors_volt(struct text_object *obj, char *p, int p_max_size) {
+void print_obsd_sensors_volt(struct text_object *obj, char *p,
+                             unsigned int p_max_size) {
   obsd_sensors.device = sensor_device.get(*state);
   update_obsd_sensors();
   snprintf(p, p_max_size, "%.2f",
@@ -514,7 +503,7 @@ void print_obsd_sensors_volt(struct text_object *obj, char *p, int p_max_size) {
 
 /* chipset vendor */
 void get_obsd_vendor(struct text_object *obj, char *buf,
-                     size_t client_buffer_size) {
+                     unsigned int client_buffer_size) {
   int mib[2];
   char vendor[64];
   size_t size = sizeof(vendor);
@@ -534,7 +523,7 @@ void get_obsd_vendor(struct text_object *obj, char *buf,
 
 /* chipset name */
 void get_obsd_product(struct text_object *obj, char *buf,
-                      size_t client_buffer_size) {
+                      unsigned int client_buffer_size) {
   int mib[2];
   char product[64];
   size_t size = sizeof(product);
@@ -628,38 +617,51 @@ cleanup:
 }
 #endif
 
-void clear_diskio_stats() {}
+int update_diskio() { return 0; /* XXX: implement? hifi: not sure how */ }
 
-struct diskio_stat *prepare_diskio_stat(const char *s) {}
-
-void update_diskio() { return; /* XXX: implement? hifi: not sure how */ }
-
-/* While topless is obviously better, top is also not bad. */
+// conky uses time in hundredths of seconds (centiseconds)
+static unsigned long to_conky_time(u_int32_t sec, u_int32_t usec) {
+  return sec * 100 + (unsigned long)(usec * 0.0001);
+}
 
 void get_top_info(void) {
-  struct kinfo_proc2 *p;
+  struct kinfo_proc *p;
   struct process *proc;
   int n_processes;
   int i;
 
   kvm_init();
 
-  p = kvm_getproc2(kd, KERN_PROC_ALL, 0, sizeof(struct kinfo_proc2),
+  p = kvm_getprocs(kd, KERN_PROC_ALL, 0, sizeof(struct kinfo_proc),
                    &n_processes);
 
+  // NOTE(gmb): https://github.com/openbsd/src/blob/master/sys/sys/sysctl.h
   for (i = 0; i < n_processes; i++) {
-    if (!((p[i].p_flag & P_SYSTEM)) && p[i].p_comm != nullptr) {
-      proc = find_process(p[i].p_pid);
-      if (!proc) proc = new_process(p[i].p_pid);
+    if (!((p[i].p_flag & P_SYSTEM)) && p[i].p_comm[0] != 0) {
+      proc = get_process(p[i].p_pid);
+      if (!proc) continue;
 
       proc->time_stamp = g_time;
-      proc->name = strndup(p[i].p_comm, text_buffer_size);
+      proc->user_time = to_conky_time(p[i].p_uutime_sec, p[i].p_uutime_usec);
+      proc->kernel_time = to_conky_time(p[i].p_ustime_sec, p[i].p_ustime_usec);
+      proc->total = proc->user_time + proc->kernel_time;
+      proc->uid = p[i].p_uid;
+      proc->name = strndup(p[i].p_comm, text_buffer_size.get(*state));
+      proc->basename = strndup(p[i].p_comm, text_buffer_size.get(*state));
       proc->amount = 100.0 * p[i].p_pctcpu / FSCALE;
-      /* TODO: vsize, rss, total_cpu_time */
+      proc->vsize = p[i].p_vm_map_size;
+      proc->rss = (p[i].p_vm_rssize * getpagesize());
+      proc->total_cpu_time = to_conky_time(p[i].p_rtime_sec, p[i].p_rtime_usec);
     }
   }
 }
 
+void get_battery_short_status(char *buffer, unsigned int n, const char *bat) {
+  /* Not implemented */
+  (void)bat;
+  if (buffer && n > 0) memset(buffer, 0, n);
+}
+
 /* empty stubs so conky links */
 void prepare_update() {}
 
