@@ -39,6 +39,9 @@
 // don't use spaces in LOGGRAPH or NORMGRAPH if you change them
 #define LOGGRAPH "-l"
 #define TEMPGRAD "-t"
+#define INVERTX "-x"
+#define INVERTY "-y"
+#define MINHEIGHT "-m"
 
 enum class text_node_t : uint32_t {
   NONSPECIAL = 0,
@@ -80,6 +83,10 @@ struct special_node {
   Colour last_colour;
   short font_added;
   char tempgrad;
+  char speedgraph;
+  char invertx;
+  char inverty;
+  int minheight;
   struct special_node *next;
 };
 
@@ -97,7 +104,7 @@ const char *scan_gauge(struct text_object *, const char *, double);
 #ifdef BUILD_GUI
 void scan_font(struct text_object *, const char *);
 std::pair<char *, size_t> scan_command(const char *);
-bool scan_graph(struct text_object *, const char *, double);
+bool scan_graph(struct text_object *, const char *, double, char);
 void scan_tab(struct text_object *, const char *);
 void scan_stippled_hr(struct text_object *, const char *);
 
