@@ -33,6 +33,9 @@
 #include "x11.h"
 
 #include <X11/X.h>
+#include <X11/Xlibint.h>
+#undef min
+#undef max
 #include <sys/types.h>
 
 #include "common.h"
@@ -314,6 +317,8 @@ void update_x11_resource_db(bool first_run) {
       XrmDestroyDatabase(db);
     }
 
+    // https://github.com/dunst-project/dunst/blob/master/src/x11/x.c#L499
+    display->db = NULL; // should be new or deleted
     db = XrmGetStringDatabase((const char *)prop.value);
     XrmSetDatabase(display, db);
   }
@@ -635,7 +640,9 @@ void x11_init_window(lua::state &l, bool own) {
 #endif /* BUILD_XSHAPE */
       if (own_window_type.get(l) == window_type::DOCK ||
           own_window_type.get(l) == window_type::PANEL) {
-        // wmHint.initial_state = WithdrawnState;
+        // Docks and panels MUST have WithdrawnState initially
+        // See: https://github.com/brndnmtthws/conky/issues/2046
+        wmHint.initial_state = WithdrawnState;
       } else {
         wmHint.initial_state = NormalState;
       }
