@@ -51,6 +51,7 @@
 // TODO: remove lua requirement from x11_init_window
 #include "llua.h"
 
+#include "geometry.h"
 #include "gui.h"
 
 /* true if use_argb_visual=true and argb visual was found*/
@@ -58,7 +59,10 @@ extern bool have_argb_visual;
 
 #define ATOM(a) XInternAtom(display, #a, False)
 
+/// @brief Display where conky is placed
 extern Display *display;
+/// @brief Screen with conky
+extern int screen;
 
 struct conky_x11_window {
   /// XID of x11 root window
@@ -88,16 +92,14 @@ struct conky_x11_window {
   std::int32_t xi_opcode;
 #endif /* BUILD_MOUSE_EVENTS || BUILD_XINPUT */
 
-  int width;
-  int height;
-#ifdef OWN_WINDOW
-  int x;
-  int y;
-#endif
+  /// @brief Window geometry in screen coordinate space
+  conky::rect<int> geometry;
 };
 
 extern struct conky_x11_window window;
 
+void update_x11_resource_db(bool first_run = false);
+void update_x11_workarea();
 void init_x11();
 void destroy_window(void);
 void create_gc(void);
@@ -132,12 +134,13 @@ std::vector<Window> x11_atom_window_list(Display *display, Window window,
 ///
 /// If neither of the atoms are provided, this function tries traversing the
 /// window graph in order to collect windows. In this case, map state of windows
-/// is ignored. This also produces a lot of noise for some WM/DEs due to
-/// inserted window decorations.
+/// is ignored.
 ///
-/// @param display which display to query for windows @return a (likely) ordered
-/// list of windows
-std::vector<Window> query_x11_windows(Display *display);
+/// @param display which display to query for windows
+/// @param eager fallback to very slow tree traversal to ensure a list of
+/// windows is returned even if window list atoms aren't defined
+/// @return a (likely) ordered list of windows
+std::vector<Window> query_x11_windows(Display *display, bool eager = false);
 
 /// @brief Finds the last ascendant of a window (trunk) before root.
 ///
@@ -155,7 +158,7 @@ Window query_x11_top_parent(Display *display, Window child);
 /// @param x screen X position contained by window
 /// @param y screen Y position contained by window
 /// @return a top-most window at provided screen coordinates, or root
-Window query_x11_window_at_pos(Display *display, int x, int y);
+Window query_x11_window_at_pos(Display *display, conky::vec2i pos);
 
 /// @brief Returns a list of windows overlapping provided screen coordinates.
 ///
@@ -169,9 +172,10 @@ Window query_x11_window_at_pos(Display *display, int x, int y);
 /// (besides bounds testing).
 /// @return a vector of windows at provided screen coordinates
 std::vector<Window> query_x11_windows_at_pos(
-    Display *display, int x, int y,
+    Display *display, conky::vec2i pos,
     std::function<bool(XWindowAttributes &)> predicate =
-        [](XWindowAttributes &a) { return true; });
+        [](XWindowAttributes &a) { return true; },
+    bool eager = false);
 
 #ifdef BUILD_XDBE
 void xdbe_swap_buffers(void);
